﻿


/******** readme file for Bogart Party connections, interest groups, and the slow diffusion of infrastructure   *****/

/*****note unless stated all do files are run in Stata 14******/

/**********tables for main text***********/

/******** table 1  *****/

clear

insheet using suppoppdataaug82016_public.txt

	/******** note the suppoppdataaug82016_public file is organized by bill and contains summary information on the bill and then by 782 Blome towns that might support or oppose the bill*****/

	/******** variable description  *****/
		/******** river_bill_name is name of bill *****/
		/******** suppoppbillid is unique id for each bill *****/
		/******** river_bill_id is seperate id for each bill but is incomplete*****/
		/******** driveract is an indicator coded one if the bill was successful*****/
		/******** billact_year identifies the last year of the parliament where the bill was introduced*****/	
		/******** startedpetitionerindicator is an indicator coded one if there was a petitioner that started the bill in the Commons journals. 1 if yes and 0 if no starting petitioner*****/
		/******** townpetition_indicator is an indicator coded one if a town in Blome was the starting petitioner that led to the bill. 1 if yes and 0 if a town was not the petitioner. Note field is empy if there is no stated petitioner*****/
		/******** townpetition1_name is the name of the first town if a town started the petition that led to bill. Note field is empty if there is no stated petitioner*****/
		/******** townpetition2_name is the name of the second town if a town started the petition that led to bill. Note field is empty if there is no stated petitioner*****
		/******** totaltownoppose is the number of towns that opposed a bill*****/
		/******** totaltownsupp is the number of towns that supported a bill*****/			
		/******** dlandownersadjaentoppose is an indicator coded one if the bill was opposed by landowners adjacent to river. Note all the entries for each bill have ones or zeros for opposition*****/
		/******** quartersessionsoppose identifies which justices of the peace in quarter sessions opposed the bill if any*****/
		/******** dquarteroppose is an indicator coded one if the bill was opposed by any justices in  quarter session. note all the entries for each bill have ones or zeros for opposition*****/
		/******** quartersessionssupport identifies which justices of the peace in quarter sessions supported the bill if any*****/
		/******** dquartersupport is an indicator coded one if the bill was supported by any justices in  quarter session note all the entries for each bill have ones or zeros for support*****/
		/******** citysupportoppose identifies all towns in blome that could oppose or support the bill*****/
		/******** citysupportopposecounty identifies the county of the town in blome that could oppose or support the bill*****/
		/******** citysupportopposeid is the assigned id of the town in blome that could oppose or support the bill*****/
		/******** doppose is an indicator coded one if the town opposed the bill*****/
		/******** dsupport is an indicator coded one if the town supported the bill*****/
		/******** harbour1670 is an indicator coded one if possible supporting or opposing town had a harbour c.1670 according to Blome*****/
		/******** mining1670 is an indicator coded one if possible supporting or opposing town had mining c.1670 according to Blome*****/
		/******** manufact1670 is an indicator coded one if possible supporting or opposing town had manufacturing c.1670 according to Blome*****/
		/******** rivernav1670 is an indicator coded one if possible supporting or opposing town had river navigation or was on coast c.1670 according to Blome*****/
		/******** morden1700 is an indicator coded one if possible supporting or opposing town was on a highway in Morden maps c.1700*****/
		/******** freeschool1670 is an indicator coded one if possible supporting or opposing town had a free school c.1670 according to Blome*****/
		/******** civicgov1670 is an indicator coded one if possible supporting or opposing town had a mayor or city council c.1670 according to Blome*****/		
		/******** localmarketpotinc is the local market potential of the possible supporting or opposing town *****/	
		/******** citysupportopposexco is the latitude or x coordinate of the possible supporting or opposing town *****/
		/******** citysupportopposeyco is the longitude or y coordinate of the possible supporting or opposing town *****/
		/******** mostdownstreamcandidatetown is the name of the most downstream candidate town associated with the bill *****/
		/******** candidatetownxco1 is the latitude or x coordinate of the most downstream candidate town associated with the bill  *****/
		/******** candidatetownyco1 is the longitude or y coordinate of the most downstream candidate town associated with the bill  *****/
		/******** disttocandidate is the straight line distance in miles from the possible supporting or opposing town and the most downstream candidate town associated with the bill  *****/
		/******** downstream is an indicator coded one if the possible supporting or opposing town is downstream from the most downstream candidate town associated with the bill. for definition of downstream see text*****/
		
	

		
		
		
	/******** matching of bills to candidate towns description  *****/		
		/******** town1matched is the name of the first candidate town matched to a bill*****/
		/******** town2matched is the name of the second candidate town matched to a bill*****/
		/******** town3matched is the name of the third candidate town matched to a bill*****/
		/******** town4matched is the name of the fourth candidate town matched to a bill*****/
		/******** town5matched is the name of the fifth candidate town matched to a bill*****/
		/******** town6matched is the name of the sixth candidate town matched to a bill*****/



	/******** entries in Panel A table 1  *****/
		/******** first entry of table 1, number of bills is total max value of suppoppbillid or 69 *****/
		/******** number of river acts is the sum of driveract divided by the number of Blome towns 782 or the average of driveract times the number of bills or 32*****/
		/******** the percentage of bills is 100 times the average of driveract   *****/	
		/******** the average number of bills per parliament is 69 divided by 14 the number of parliaments from 1690 to 1741  *****/
		/******** the average number of acts per parliament is 32 divided by 14 the number of parliaments  from 1690 to 1741*****/

	/******** entries in Panel B table 1*****/

		/******** the number of bills starting with a petition is the sum of startedpetitionerindicator. The percentage is the average of startedpetitionerindicator   *****/
		/******** the number of bills with towns starting the petition is the sum of townpetition_indicator and the percent is the avearge of townpetition_indicator   *****/
	
	/******** entries in Panel C table 1*****/
	

	
	
		/******** the number of bills with towns supporting is the identified by the number of observations in billswithtownsupport below. The percentage is the total divided by 69   *****/
			
			gen billswithtownsupport=1 if totaltownsupp>0
			replace billswithtownsupport=. if totaltownsupp==.
			summarize billswithtownsupport
			
		/******** if a bill has town supporting how many towns supported is given by the average of totaltownsupp    *****/
	
		summarize totaltownsupp if billswithtownsupport==1
	
	
		/******** the number of bills with towns opposing is the identified by the number of observations in billswithtownoppose below. The percentage is the total divided by 69   *****/
	
			gen billswithtownoppose=1 if totaltownoppose>0
			replace billswithtownoppose=. if totaltownoppose==.
			summarize billswithtownoppose
	
		/******** if a bill has town opposing how many towns supported is given by the average of totaltownoppose    *****/
			summarize totaltownoppose if billswithtownoppose==1
			
			
		/******** number of bills with adjacent landowners opposing is given by the average of dlandownersadjaentoppose mutiplied by 69. The percentage is obtained by multiplying by 100******/

					
			replace dlandownersadjaentoppose=0 if dlandownersadjaentoppose==.
			summarize dlandownersadjaentoppose
			
		/******** number of bills with justices of the peace in quarter sessions opposing is given by the average of dquarteroppose mutiplied by 69. The percentage is obtained by multiplying by 100******/

			replace dquarteroppose=0 if dquarteroppose==.
			summarize dquarteroppose
		
		/******** number of bills with justices of the peace in quarter sessions supporting is given by the average of dquartersupport mutiplied by 69. The percentage is obtained by multiplying by 100******/

			replace dquartersupport=0 if dquartersupport==.
			summarize dquartersupport
		
		
/******** table 2  *****/

clear

insheet using townsmatchaug82016_public.txt	


	/******** note the townsmatchaug82016_public file is organized by towns listed in Blome. Some are matched to bills and acts *****/
	
	/******** variable description  *****/
		
		/******** city is town name from Blome *****/
		/******** county is  town county from Blome *****/
		/******** cityid is town assigned id number *****/
		/******** rivernav1670alt is an indicator coded one if Blome states the market town has a navigable river or is located on coast, there are some exceptoins. If a petition in Commons states river is not navigable then it is coded as zero*****/
		/******** outsample is an indicator coded one if rivernav1670alt is one and if town does not have water based on water features in Blome's maps*****/
		/******** riveract1670_1741 is an indicator coded one if town ever had a river act between 1690 and 1741*****/
		/******** driverbill1690_1741 is an indicator coded one if town ever had a river bill between 1690 and 1741*****/	
		/******** numberofriverbills is the number of river bills for the town between 1690 and 1741*****/						
		/******** rivbillid1 is unique id for towns first river bill*****/	
		/******** rivbillid2 is unique id for towns second river bill*****/
		/******** rivbillid3 is unique id for towns third river bill*****/
		/******** rivbillid4 is unique id for towns fourth river bill*****/	
		/******** failfirst is indicator coded one if the town ever had a bill that failed on its first try in parliament*****/				
		/******** iffailnumberfailis is the number of failed bills matched to the town if it ever had a failed bill*****/	
		/******** iffailsucceedlaterinsample is an indicator coded one if the town had a failed bill and it succeeded in the sample period ending in 1741*****/
		/******** iffailyearfirstbill is the year of the parliament where the towns first bill was introduced*****/	
		/******** yearact is the year of parliament where the towns first river act was passed*****/	
		/******** iffailsucceedtimeinsample is the number of years between a towns act and its first fail if it had a first fail and succeeded in sample*****/	
		/******** iffailsucceedlateroutsample is an indicator coded one if the town had a failed bill and it succeed in sample or later by 1830*****/
		/******** iffailsucceedlateryearofact is the year where the towns first river act was passed if it eventually succeded out of sample or after 1741*****/	
		/******** iffailsucceedtimeoutsample is the number of years between a towns act and its first failed bill if it had a first fail and succeeded in or out of sample*****/
		/******** canal_yes_1 is an indicator coded one if the town had a failed bill and it succeeded later out of sample by 1830 and was a canal act*****/
		/******** yearfirstbillall is the year where the towns first river or canal bill was introduced up to 1830 if it had at least one bill introduced before 1741*****/	
		/******** yearfirstactall is the year where the towns first river or canal act was passed up to 1830 if it had at least one bill introduced before 1741 and eventually had a successful act by 1830*****/	
							
	/******** entries in Panel A table 2  *****/
	
		/******** number of towns with navigable rivers or coast equals number observations in the following summary*****/

		summarize rivernav1670alt if rivernav1670alt==1 
		
		/******** number of towns without navigable rivers and no water equals number observations in the following summary*****/

		summarize outsample if rivernav1670alt==0 & outsample==1
				
				
		/******** number of candidate towns or also known as towns without navigable rivers and with water number observations in the following summary*****/

		summarize rivernav1670alt if rivernav1670alt==0 & outsample==0
				
	/******** entries in Panel B table 2  *****/		
		
		/******** number of candidate towns matched with river bills by 1741 equals number observations in the following summary*****/

		summarize driverbill1690_1741 if driverbill1690_1741==1 

		/******** number of candidate towns with river acts by 1741 number observations in the following summary*****/

		summarize riveract1670_1741 if riveract1670_1741==1
		
		/******** number of river bills for candidate towns across parliaments is the sum of numberofriverbills across towns or the maximum value of temp1 below*****/
	
		gen temp1=sum(numberofriverbills)
		summarize temp1
		drop temp1

	/******** entries in Panel C table 2  *****/
	
		/******** percentage of towns with failed river bill on first try is mean of failfirst multiplied by 100 in the sample of candidate towns with at least one river bill between 1690 and 1741*****/
	
		summarize failfirst if driverbill1690_1741==1
	
		/******** percentage of towns with failed river bill on first try that got river act by 1741 equal to mean of iffailsucceedlaterinsample multiplied by 100*****/

		summarize iffailsucceedlaterinsample
		
		/******** for towns with failed river bill on first try and got river act by 1741, average years until successful bill equals mean of iffailsucceedtimeinsample *****/
	
		summarize iffailsucceedtimeinsample
		
		
		/******** percentage of towns with failed river bill on first try that got river or canal act by 1830 equals mean of iffailsucceedlateroutsample multiplied by 100*****/
	
		summarize iffailsucceedlateroutsample
		
		
		/******** for towns with failed river bill on first try and got river or canal act by 1830, average years until successful bill equals mean of iffailsucceedtimeoutsample*****/
	
		summarize  iffailsucceedtimeoutsample

		
		/******** average years from first bill to successful bill if get river or canal act by 1830 mean of timetoactever defined below*****/
	

		gen timetoactever=yearfirstactall-yearfirstbillall

		summarize timetoactever
		
		
		
/******** table 3  *****/

clear

insheet using suppoppdataaug82016_public.txt

	/******** for variable definitions see above  *****/
	
	
	
	/******** entries in Panel A table 3  *****/
		/******** if a town supports or opposes then the average distance to most downstream candidate town is give by the summary below. The same for the standard deviation  *****/

		summarize disttocandidate if dsupport==1

		summarize disttocandidate if doppose==1
	
	/******** entries in Panel B table 3  *****/		
			/*** define a variable petition to identify if a town supports or opposes***/
		
			gen petition=.
			replace petition=1 if dsupport==1
			replace petition=1 if doppose==1
			
			/*** define a variable petitionboth to identify if a town supports and opposes ***/
		
			gen petitionboth=0
			replace petitionboth=1 if dsupport==1 & doppose==1
		
				
			/*** test hypothesis whether towns petitioning in support are more or less likely to be downstream than towns that petition in opposition. Note towns  supporting and opposing are dropped***/	
		
			ttest downstream if petition==1 & petitionboth==0, by(dsupport)

						
			/*** test hypothesis whether towns petitioning in support are more or less likely to be downstream than towns that petition in opposition. Note here candidate towns are dropped. also towns  supporting and opposing are dropped***/	
		
			ttest downstream if petition==1 & petitionboth==0 & disttocandidate>0, by(dsupport)
		
		
		

/******** figure 4  *****/
		
	twoway kdensity disttocandidate if dsupport==1 || kdensity disttocandidate if doppose==1, legend(order(1 "Support" 2 "oppose")) xtitle(Distance to Upstream Candidate Town in Mi.) ytitle(Density) title(Figure 4: Distance to Candidate Towns: Kernal Dens. Estimates)
	
	
/******** table 4  *****/	

clear

insheet using rivactpanelaug82016_public.txt

	/***note this file is organized by candidate towns*****/

	/******** town variable definitions  *****/

		/******** city is candidate town name from Blome *****/
		/******** county is candidate town county from Blome *****/
		/******** cityid is candidate town assigned id number *****/
		/******** townxco is the latitude or x coordinate of the candidate town  *****/
		/******** townyco is the longitude or y coordinate of the candidate town  *****/
		/******** connectioncity is the navigation head. also called the connection city for candidate town  *****/
		/******** xcoconnect is the latitude or x coordinate of the candidate town's connection city  *****/
		/******** ycoconnect is the longitude or y coordinate of the candidate town's connection city *****/
		/******** popconnectcity is the estimated population of the candidate town's connection city. see text for esimates of population *****/

	/******** town characteristic variable definitions, See text for definition of each variable *****/

		/******** elev is elevation change in feet from candidate town to navigation head. Also called connection city  *****/
		/******** dist is distance from candidate town in miles to navigation head. Also called connection city *****/
		/******** harbour1670 is indicator for candidate town having harbour c.1670 according to Blome*****/
		/******** mining1670 is indicator for candidate town having mining c.1670 according to Blome*****/
		/******** manufact1670 is indicator for candidate town having manufacturing c.1670 according to Blome*****/
		/******** morden1700 is indicator for candidate town being connected to Morden map road c.1700 according to Morden*****/
		/******** freeschool1670 is indicator for candidate town having a free school c.1670 according to Blome*****/
		/******** alms1670 is indicator for candidate town having an alms house c.1670 according to Blome*****/
		/******** civicgov1670 is indicator for candidate town with municipal government or having a mayor or city council c.1670 according to Blome*****/
		/******** localmarketpotinc is the local market potential of the candidate town *****/	

	


	/******** river bill and act variable definitions *****/
 	
		/******** year is the last year of the parliament*****/
		/******** year2 is a count variable for each parliament*****/
		/******** whig is an indicator coded one if the whig party has a majority in parliament*****/
		/******** changemaj is an indicator coded one if there was a change in the majority party between the current and previous parliament*****/
		/******** drivbill is indicator for candidate town had a river bill in that parliament*****/
		/******** drivact is indicator for candidate town had a river act in that parliament*****/
		/******** rivbillid is the assigned id for each river bill*****/
		/******** drivdrop is an indicator coded one if the candidate town got a river act in a previous parliament and should be dropped from adoption regression*****/
		/********  for candidate towns that had bills in a parliament totaltownoppose is the number of towns that opposed **/
		/********  for candidate towns that had bills in a parlimaent landadjoppose is an indicator coded one if landowners adjacent opposed ***/
		/********  for candidate towns that had bills in a parlimaent quarteroppose is an indicator coded one if justices in quarter sessions opposed ***/
		/********  for candidate towns that had bills in a parlimaent totaltownsupp is the number of towns that supported ***/
		/********  for candidate towns that had bills in a parlimaent quartersupp is an indicator coded one if justices in quarter sessions supported ***/ 
		/******** riveract1670_1741 is an indicator coded one if candidate town ever had a river act between 1690 and 1741*****/
		/******** driverbill1690_1741 is an indicator coded one if the candidate town ever had a river bill between 1690 and 1741*****/	
		/******** failfirst is indicator coded one if the candidate town ever had a bill that failed on its first try in parliament*****/				
		/******** iffailsucceedlaterinsample is an indicator coded one if the candidate town had a failed bill and it succeeded in the sample period ending in 1741*****/	
		/******** iffailsucceedlateroutsample is an indicator coded one if the candidate town had a failed bill and it succeed in sample or later by 1830*****/

	/******** variables for neighboring town characteristics within 25 miles definitions*****/
		/******** harbour25up is the number of upstream towns within 25 miles with harbours *****/	
		/******** harbour25down is the number of downstream towns within 25 miles with harbours *****/	
		/******** mining25up is the number of upstream towns within 25 miles with mining *****/	
		/******** mining25down is the number of downstream towns within 25 miles with mining *****/
		/******** manufact25up is the number of upstream towns within 25 miles with manufacturing *****/	
		/******** manufact25down is the number of downstream towns within 25 miles with manufacturing *****/
		/******** rivernav25up is the number of upstream towns within 25 miles with river navigation or on coast *****/	
		/******** rivernav25down is the number of downstream towns within 25 miles with river navigation or on coast *****/
		/******** morden25up is the number of upstream towns within 25 miles on highways according to morden maps *****/	
		/******** morden25down is the number of downstream towns within 25 miles on highways according to morden maps *****/
		/******** freeschool25up is the number of upstream towns within 25 miles with free schools *****/	
		/******** freeschool25down is the number of downstream towns within 25 miles with free schools  *****/
		/******** civic25up is the number of upstream towns within 25 miles with municipal govt *****/	
		/******** civic25down is the number of downstream towns within 25 miles with municipal govt   *****/
		
	/******** variables for neighboring political constituencies within 25 miles definitions *****/
		/******** mps25up_a15 is the number of upstream mps within 25 miles of candidate town*****/	
		/******** mps25down_a15 is the number of downstream mps within 25 miles of candidate town*****/	
		/******** rps25up_a15 is the number of upstream majority party mps within 25 miles of candidate town*****/	
		/******** rps25down_a15 is the number of downstream majority party mps within 25 miles of candidate town*****/	
		/******** cont25up_a15 is the number of upstream contested constituencies within 25 miles of candidate town*****/	
		/******** cont25down_a15 is the number of downstream contested constituencies within 25 miles of candidate town*****/	
		/******** incum25up_a15 is the number of upstream incumbent mps within 25 miles of candidate town*****/	
		/******** incum25down_a15 is the number of downstream incumbent mps within 25 miles of candidate town*****/	
		/******** rpcounty_m15 is the number of majority party mps in candidate town's county*****/	
		/******** rpclosest_j15 is the number of majority party mps in candidate town's closest constituency*****/	
		/******** rpcountyexog is the number of inumbent majority party mps in candidate town's county*****/	
		/******** rpclosestexog is the number of incumbent majority party mps in candidate town's closest constituency*****/
		/******** rps25upexog_a15 is the number of incumbent upstream majority party mps within 25 miles of candidate town*****/	
		/******** rps25downexog_a15 is the number of incumbent downstream majority party mps within 25 miles of candidate town*****/	
	

	/******** variables for other acts in neighboring towns within 25 miles, 20 miles, 30 miles definitions *****/
		/******** pike25prev is the number of towns within 25 miles of candidate town with turnike acts by previous parliament*****/	
		/******** river25prev is the number of towns within 25 miles of candidate town with river acts by previous parliament*****/	
		/******** pike20prev is the number of towns within 20 miles of candidate town with turnike acts by previous parliament*****/	
		/******** river20prev is the number of towns within 20 miles of candidate town with river acts by previous parliament*****/	
		/******** pike30prev is the number of towns within 30 miles of candidate town with turnike acts by previous parliament*****/	
		/******** river30prev is the number of towns within 30 miles of candidate town with river acts by previous parliament*****/	
		
		
	/******** region variable definitions *****/
		/******** southeast is an indicator coded as one if candidate town is in southeast region*****/
		/******** southwest is an indicator coded as one if candidate town is in southwest region*****/
		/******** eastmid is an indicator coded as one if candidate town is in eastmid region*****/
		/******** westmid is an indicator coded as one if candidate town is in westmid region*****/
		/******** north is an indicator coded as one if candidate town is in north region*****/
		/******** wales is an indicator coded as one if candidate town is in wales region*****/
		
	/******** parliament varying macro variable definitions see Bogart 2011 and text for details *****/
		/******** parllength is the number of years in the parliament*****/
		/******** foreignwar is the fraction of years in the parliament that Britain was in a foreign war*****/
		/******** badharvest is the fraction of years in the parliament where Britain had a bad harvest*****/
		/******** inflation is the average inflation rate for years in the parliament *****/
		/******** rorclark is the average rate of return on charities from Clark's study for years in the parliament *****/
		/******** avgrowthcoastal is the average growth rate of coastal trade for years in the parliament *****/
		
		
	/******** variables for towns with Whig and Tory strongholds in nearby constituencies *****/
		/******** whigstrong0115_25up_a15 is the number of Whig strongholds in upstream constituencies within 25 miles of candidate town*****/	
		/******** whigstrong0115_25down_a15 is the number of whig strongholds downstream in constituencies within 25 miles of candidate town*****/	
		/******** torystrong0115_25up_a15 is the number of Tory strongholds in upstream constituencies within 25 miles of candidate town*****/	
		/******** torystrong0115_25down_a15 is the number of Tory strongholds downstream in constituencies within 25 miles of candidate town*****/	
		/******** rpcountywhigstrong0115 is a whig stronghold in candidate town's county*****/	
		/******** rpcountytorystrong0115 is a Tory stronghold in candidate town's county*****/	
	
	/******** variables for number of mps from constituencies with competitive elections near candidate town *****/
		/******** rpcountycont is number of majority party mps from contested elections in candidate town's county*****/
		/******** rpclosestcont is number of majority party mps from contested elections in candidate town's nearest constituency*****/
		/******** rps25contup_a15 is number of majority party mps in upstream constituencies with contested elections within 25 miles of candidate town*****/
		/******** rps25contdown_a15 is number of majority party mps in downstream constituencies with contested elections within 25 miles of candidate town*****/
		/******** countycont is an indicator coded one if the candidate town's county had a contested election*****/

	/******** variables for neighboring political constituencies within 20 miles definitions *****/
		/******** mps20up_a15 is the number of upstream mps within 20 miles of candidate town*****/	
		/******** mps20down_a15 is the number of downstream mps within 20 miles of candidate town*****/	
		/******** rps20up_a15 is the number of upstream majority party mps within 20 miles of candidate town*****/	
		/******** rps20down_a15 is the number of downstream majority party mps within 20 miles of candidate town*****/	
		/******** cont20up_a15 is the number of upstream contested constituencies within 20 miles of candidate town*****/	
		/******** cont20down_a15 is the number of downstream contested constituencies within 20 miles of candidate town*****/	
		/******** incum20up_a15 is the number of upstream incumbent mps within 20 miles of candidate town*****/	
		/******** incum20down_a15 is the number of downstream incumbent mps within 20 miles of candidate town*****/	

	/******** variables for neighboring town characteristics within 20 miles definitions*****/
		/******** harbour20up is the number of upstream towns within 20 miles with harbours *****/	
		/******** harbour20down is the number of downstream towns within 20 miles with harbours *****/	
		/******** mining20up is the number of upstream towns within 20 miles with mining *****/	
		/******** mining20down is the number of downstream towns within 20 miles with mining *****/
		/******** manufact20up is the number of upstream towns within 20 miles with manufacturing *****/	
		/******** manufact20down is the number of downstream towns within 20 miles with manufacturing *****/
		/******** rivernav20up is the number of upstream towns within 20 miles with river navigation or on coast *****/	
		/******** rivernav20down is the number of downstream towns within 20 miles with river navigation or on coast *****/
		/******** morden20up is the number of upstream towns within 20 miles on highways according to morden maps *****/	
		/******** morden20down is the number of downstream towns within 20 miles on highways according to morden maps *****/
		/******** freeschool20up is the number of upstream towns within 20 miles with free schools *****/	
		/******** freeschool20down is the number of downstream towns within 20 miles with free schools  *****/
		/******** civic20up is the number of upstream towns within 20 miles with municipal govt *****/	
		/******** civic20down is the number of downstream towns within 20 miles with municipal govt   *****/		


	/******** variables for neighboring political constituencies within 30 miles definitions *****/
		/******** mps30up_a15 is the number of upstream mps within 30 miles of candidate town*****/	
		/******** mps30down_a15 is the number of downstream mps within 30 miles of candidate town*****/	
		/******** rps30up_a15 is the number of upstream majority party mps within 30 miles of candidate town*****/	
		/******** rps30down_a15 is the number of downstream majority party mps within 30 miles of candidate town*****/	
		/******** cont30up_a15 is the number of upstream contested constituencies within 30 miles of candidate town*****/	
		/******** cont30down_a15 is the number of downstream contested constituencies within 30 miles of candidate town*****/	
		/******** incum30up_a15 is the number of upstream incumbent mps within 30 miles of candidate town*****/	
		/******** incum30down_a15 is the number of downstream incumbent mps within 30 miles of candidate town*****/	

	/******** variables for neighboring town characteristics within 30 miles definitions*****/
		/******** harbour30up is the number of upstream towns within 30 miles with harbours *****/	
		/******** harbour30down is the number of downstream towns within 30 miles with harbours *****/	
		/******** mining30up is the number of upstream towns within 30 miles with mining *****/	
		/******** mining30down is the number of downstream towns within 30 miles with mining *****/
		/******** manufact30up is the number of upstream towns within 30 miles with manufacturing *****/	
		/******** manufact30down is the number of downstream towns within 30 miles with manufacturing *****/
		/******** rivernav30up is the number of upstream towns within 30 miles with river navigation or on coast *****/	
		/******** rivernav30down is the number of downstream towns within 30 miles with river navigation or on coast *****/
		/******** morden30up is the number of upstream towns within 30 miles on highways according to morden maps *****/	
		/******** morden30down is the number of downstream towns within 30 miles on highways according to morden maps *****/
		/******** freeschool30up is the number of upstream towns within 30 miles with free schools *****/	
		/******** freeschool30down is the number of downstream towns within 30 miles with free schools  *****/
		/******** civic30up is the number of upstream towns within 30 miles with municipal govt *****/	
		/******** civic30down is the number of downstream towns within 30 miles with municipal govt   *****/
	
	
	/******** variables for neighboring political constituencies within 25 miles and to left and right of candidate town towards navigation head definitions *****/
		/******** mps25left_a15 is the number of upstream mps within 25 miles to the left of candidate town*****/	
		/******** mps25right_a15 is the number of downstream mps within 25 miles to the right of candidate town*****/	
		/******** rps25left_a15 is the number of upstream majority party mps within 25 miles to the left of candidate town*****/	
		/******** rps25right_a15 is the number of downstream majority party mps within 25 miles to the right of candidate town*****/	
		/******** cont25left_a15 is the number of upstream contested constituencies within 25 miles to the left of candidate town*****/	
		/******** cont25right_a15 is the number of downstream contested constituencies within 25 miles to the right of candidate town*****/	
		/******** incum25left_a15 is the number of upstream incumbent mps within 25 miles to the left of candidate town*****/	
		/******** incum25right_a15 is the number of downstream incumbent mps within 25 miles to the right of candidate town*****/	

	/******** variables for neighboring town characteristics within 25 miles and to left and right of candidate town towards navigation head definitions *****/
		/******** harbour25left is the number of upstream towns within 25 miles to the left of candidate town with harbours *****/	
		/******** harbour25right is the number of downstream towns within 25 miles to the right of candidate towns with harbours *****/	
		/******** mining25left is the number of upstream towns within 25 miles to the left of candidate town with mining *****/	
		/******** mining25right is the number of downstream towns within 25 miles to the right of candidate towns with mining *****/
		/******** manufact25left is the number of upstream towns within 25 miles to the left of candidate town with manufacturing *****/	
		/******** manufact25right is the number of downstream towns within 25 miles to the right of candidate towns with manufacturing *****/
		/******** rivernav25left is the number of upstream towns within 25 miles to the left of candidate town with river navigation or on coast *****/	
		/******** rivernav25right is the number of downstream towns within 25 miles to the right of candidate towns with river navigation or on coast *****/
		/******** morden25left is the number of upstream towns within 25 miles to the left of candidate town on highways according to morden maps *****/	
		/******** morden25right is the number of downstream towns within 25 miles to the right of candidate towns on highways according to morden maps *****/
		/******** freeschool25left is the number of upstream towns within 25 miles to the left of candidate town with free schools *****/	
		/******** freeschool25right is the number of downstream towns within 25 miles to the right of candidate towns to the left of candidate town with free schools  *****/
		/******** civic25left is the number of upstream towns within 25 miles with municipal govt *****/	
		/******** civic25right is the number of downstream towns within 25 miles to the right of candidate towns with municipal govt   *****/
	



		
	iis cityid

	xtset cityid year2

	tabulate year2, gen(yy)


	/******** rescaling variables *****/

	gen popconnectcity1000=popconnectcity/1000


	gen localmarketpotinc1000=localmarketpotinc/1000

	gen localmarketpotinc10000=localmarketpotinc/10000


	gen elev10=elev/10
	gen dist10=dist/10

	/******** region parliament trends *****/

	gen yearse=year*southeast
	gen yearsw=year*southwest
	gen yearem=year*eastmid
	gen yearwm=year*westmid
	gen yearno=year*north
	gen yearwa=year*wales


	/****first columns of table 4 all candidate towns*****/
		/****hypothesis test to see if town characteristics are different for towns with river acts. characteristics are defined in parliament ending in 1695 because characteristics are fixed for all parliaments*****/	
		
		ttest elev10 if year==1695, by(riveract1670_1741)

		ttest dist10 if year==1695, by(riveract1670_1741)

		ttest localmarketpotinc10000  if year==1695, by(riveract1670_1741)

		ttest civicgov1670  if year==1695, by(riveract1670_1741)

		ttest manufact1670  if year==1695, by(riveract1670_1741)

		ttest mining1670  if year==1695, by(riveract1670_1741)

		ttest harbour1670  if year==1695, by(riveract1670_1741)

		ttest morden1700  if year==1695, by(riveract1670_1741)

		ttest freeschool1670  if year==1695, by(riveract1670_1741)
	
	/****second columns of table 4 all candidate towns with river bill*****/
	
		ttest elev10 if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest dist10 if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest localmarketpotinc10000  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest civicgov1670  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest manufact1670  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest mining1670  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest harbour1670  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest morden1700  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest freeschool1670  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)
	
	/**** third columns of table 4 all candidate towns with river acts depedning on whether first bill failed*****/
	
		ttest elev10 if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest dist10 if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest localmarketpotinc10000  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest civicgov1670  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest manufact1670  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest mining1670  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest harbour1670  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest morden1700  if year==1695 & riveract1670_1741==1, by(failfirst)

		ttest freeschool1670  if year==1695 & riveract1670_1741==1, by(failfirst)
		
/******** table 5  *****/	

	/****panel A*****/
		
		/**** first columns all candidate towns*****/
	
		ttest morden25up if year==1695, by(riveract1670_1741)

		ttest rivernav25down if year==1695, by(riveract1670_1741)

		ttest civic25down  if year==1695, by(riveract1670_1741)

		ttest harbour25down  if year==1695, by(riveract1670_1741)

		ttest popconnectcity1000  if year==1695, by(riveract1670_1741)
		
		
		/****second columns all candidate towns with river bill*****/
	
		ttest morden25up if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest rivernav25down if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest civic25down  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest harbour25down  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)

		ttest popconnectcity1000  if year==1695 & driverbill1690_1741==1, by(riveract1670_1741)
		
	/****panel b*****/
		/****first all candidate towns*****/

		ttest pike25prev if drivdrop==0, by(drivact)

		ttest rps25down_a15 if drivdrop==0, by(drivact)

		ttest whig if drivdrop==0, by(drivact)

				
		/****second columns all candidate towns with river bills*****/

		ttest pike25prev if drivdrop==0 & drivbill==1, by(drivact)

		ttest rps25down_a15 if drivdrop==0 & drivbill==1, by(drivact)

		ttest whig if drivdrop==0 & drivbill==1, by(drivact)
		


		
/****table 6 coefficients baseline probit model for river acts****/


	/****predicted probabilities of getting river act by parliament******/

	probit drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


/****table 7 adjusted predicted probabilities of river act for selected variables****/

	probit drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)

	margins, at(elev10 ==( 1.346 26.97))

	margins, at(dist10 ==( 0.88 4.71))

	margins, at(manufact1670 ==( 0 1))

	margins, at(civicgov1670 ==(0 1))

	margins, at(localmarketpotinc10000 ==( 0.79 2.64))

	margins, at(popconnectcity1000 ==( 0.01 4.73))

	margins, at(mining25up ==( 0 1.16))

	margins, at( rivernav25up ==( 0 2.94))

	margins, at( civic25down ==( 1.068 4.296))

	margins, at( pike25prev ==( 0 6.13))

	margins, at(whig ==(0 1))

	margins, at(rpcounty_m15==(0.047 1.627))

	margins, at(rps25down_a15 ==(0.795 6.917))


/****table 8 success equation****/

	
	probit drivact  mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down pike25prev year  if drivbill==1, robust



/****table 9 success equation using margins to asses significance****/

	probit drivact  mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down pike25prev year  if drivbill==1, robust

	margins if drivbill==1, at(elev10 ==( 0.51 11.68)) 

	margins if drivbill==1, at(dist10 ==( 0.71 4.22)) 

	margins if drivbill==1, at(localmarketpotinc10000 ==( 0.73 3.78)) 

	margins if drivbill==1, at(rivernav25up ==( 0 2.49)) 

	margins if drivbill==1, at(rivernav25down ==( 0 4.69)) 

	margins if drivbill==1, at(harbour25up ==( 0 1)) 

	margins if drivbill==1, at(harbour25down ==( 0 1.34)) 

	margins if drivbill==1, at(morden25up ==( 3.82 14.06)) 

	margins if drivbill==1, at(rpcounty_m15 ==( 0.046 1.558))

	margins if drivbill==1, at(rps25down_a15 ==( 0.7 5.7)) 

	margins if drivbill==1, at(year ==(1695 1722)) 
	
/****table 10 success equation using counter-factual for towns that had bills but never got act****/

	probit drivact  mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down pike25prev year  if drivbill==1, robust

	margins if drivbill==1 & riveract1670_1741==0, at(elev10 ==( 8.73 5.97)) 

	margins if drivbill==1 & riveract1670_1741==0, at(dist10 ==( 2.71 2.73)) 

	margins if drivbill==1, at(localmarketpotinc10000 ==(  2.365 2.313)) 

	margins if drivbill==1 & riveract1670_1741==0, at(rivernav25up ==( 2.04 0.902)) 

	margins if drivbill==1 & riveract1670_1741==0, at(rivernav25down ==(  1.34 2.8)) 

	margins if drivbill==1 & riveract1670_1741==0, at(harbour25up ==( 0.217 0.294)) 

	margins if drivbill==1 & riveract1670_1741==0, at(harbour25down ==( 0.91 0.33)) 

	margins if drivbill==1 & riveract1670_1741==0, at(morden25up ==( 6.82 10.27))

	margins if drivbill==1 & riveract1670_1741==0, at(rpcounty_m15 ==( 0.91 .8)) 

	margins if drivbill==1 & riveract1670_1741==0, at(rps25down_a15 ==( 3.74 3.24)) 

	
/*******table 11 fe models********/

	/*******panel A fe models using variation using all candidate towns********/
		/****linear candidate town clustered standard errors****/

	xtreg drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa if drivdrop== 0, fe cluster(cityid)

	margins, at(rpcounty_m15==(0.047 1.627))
   

	margins, at(rps25down_a15 ==(0.795 6.917))


		/****linear candidate town Driscoll Kraay  standard errors****/
	xtscc drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa if drivdrop== 0, fe

	margins, at(rpcounty_m15==(0.047 1.627))
   

	margins, at(rps25down_a15 ==(0.795 6.917))


	/****linear candidate town PCSE with AR(1)  standard errors****/
	
	set matsize 800
	xtpcse drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa i.cityid if drivdrop== 0, correlation(ar1)

	margins, at(rpcounty_m15==(0.047 1.627))
   

	margins, at(rps25down_a15 ==(0.795 6.917))


	/****conditinal fe logit model***/ 
	
	xtlogit drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 pike25prev river25prev whig if drivdrop== 0, fe



/*****table 12****/
		/***variation in majority party MPs from incumbents***/

		gen rpclosestendog=rpclosest_j15- rpclosestexog
		gen rps25downendog_a15= rps25down_a15- rps25downexog_a15
		gen rps25upendog_a15= rps25up_a15- rps25upexog_a15
		gen rpcountyendog= rpcounty_m15- rpcountyexog

		replace rpclosestexog=. if year==1695
		replace rps25downexog_a15=. if year==1695
		replace rps25upexog_a15=. if year==1695
		replace rpcountyexog=. if year==1695

		replace rpclosestendog=. if year==1695
		replace rps25downendog_a15=. if year==1695
		replace rps25upendog_a15=. if year==1695
		replace rpcountyendog=. if year==1695

	/***create sub-sample only using variation in majority party MPs from incumbents***/

		probit drivact mps25up mps25down rpcountyexog rpclosestexog rps25upexog_a15 rps25downexog_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000  pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)

		predict www if e(sample)

		gen inexogsample=1
		replace inexogsample=. if www==.
		
		
		/***column 1 variation in majority party MPs from incumbents***/

	probit drivact mps25up mps25down rpcountyexog rpclosestexog rps25upexog_a15 rps25downexog_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)

	margins, at(rps25downexog_a15 ==(.1 4.15))
	
		/***column 2 variation in majority party MPs all***/

	probit drivact mps25up mps25down rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0 & inexogsample==1, cluster(cityid)

	margins, at(rps25down_a15 ==(1 7))
	
	
	
		/***generating a balancing sample for column 3***/
			/** start by identifying towns with high incumbents and low incumbents***/

		gen incumshare=(incum25down_a15+incum25up_a15)/(mps25down_a15 +mps25up_a15)
		gen mps25=mps25down_a15 +mps25up_a15

		
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles ≥0.5***/
			
			gen incumtreat49=0
			replace incumtreat49=1 if incumshare>.4999999
			replace incumtreat49=0 if mps25 ==0
			replace incumtreat49=. if year==1695

					
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles >0.5***/
			
			gen incumtreat50=0
			replace incumtreat50=1 if incumshare>.5
			replace incumtreat50=0 if mps25 ==0
			replace incumtreat50=. if year==1695

			
		/***column 3 sample restricted to towns with share of incumbent MPs within 25 miles ≥0.5***/

		probit drivact mps25up mps25down rpcountyexog rpclosestexog rps25upexog_a15 rps25downexog_a15 cont25up_a15 cont25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year if drivdrop==0 & year>1695 & incumtreat49==1, cluster(cityid)


		margins, at(rps25downexog_a15 ==(.29 4.65))

		/***column 4 sample restricted to towns with share of incumbent MPs within 25 miles >0.5***/

		probit drivact mps25up mps25down rpcountyexog rpclosestexog rps25upexog_a15 rps25downexog_a15 cont25up_a15 cont25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year if drivdrop==0 & year>1695 & incumtreat50==1, cluster(cityid)

		margins, at(rps25downexog_a15 ==(.48 4.96))

		
		
		
		
		
/**********Appendix II tables****************/

/*****appendix table 1 summary stats for main variables ****/

		clear

		insheet using rivactpanelaug82016_public.txt


		/******** rescaling variables *****/

		gen popconnectcity1000=popconnectcity/1000


		gen localmarketpotinc1000=localmarketpotinc/1000
	
		gen localmarketpotinc10000=localmarketpotinc/10000


		gen elev10=elev/10
		gen dist10=dist/10

		/******** region parliament trends *****/

		gen yearse=year*southeast
		gen yearsw=year*southwest
		gen yearem=year*eastmid
		gen yearwm=year*westmid
		gen yearno=year*north
		gen yearwa=year*wales
		
		/*****for description of variables see table 4 above*******/
		
		summarize drivbill drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year if drivdrop==0

/*****appendix table 2 Characteristics of towns ever petitioning in support or against bills  ****/	


	clear

	insheet using suppoppdataaug82016_public.txt
	
	/**********for variable definitions see table 1 above********/
	
	
	/*****rescale******/
	
	gen localmarket= localmarketpotinc/10000
	
	
	/******generate a variable if a town ever supported or opposed a river bill. note this value is give just once for each town associated with the first river bill with id 38***********/
	
	
	generate supportever=.
	generate opposeever=.

 	forvalues k=1/782 {
	summarize dsupport if citysupportopposeid==`k' 
	replace supportever=r(mean) if citysupportopposeid==`k'
	summarize doppose if citysupportopposeid==`k' 
	replace opposeever=r(mean) if citysupportopposeid==`k'
	}
	gen dsupportever=.
	gen dopposeever=.

	replace dsupportever=0 if river_bill_id=="38"
	replace dopposeever=0 if river_bill_id=="38"

	replace dsupportever=1 if supportever>0 & river_bill_id=="38"
	replace dopposeever=1 if opposeever>0 & river_bill_id=="38"

	summarize dsupportever

	summarize dopposeever
	
	/******generate groups that petitioned never, that petitioned never or supported, and that petitioned never or opposed.***********/
	
	
	gen petition_never=1 if river_bill_id=="38"
	replace petition_never=0 if dsupportever==1 & river_bill_id=="38"
	replace petition_never=0 if dopposeever==1 & river_bill_id=="38"

	gen petition_never_and_support=0 & river_bill_id=="38"
	replace petition_never_and_support=1 if dsupportever==1 & river_bill_id=="38"
	replace petition_never_and_support=1 if petition_never==1 & river_bill_id=="38"
	
	gen petition_never_and_oppose=0 & river_bill_id=="38"
	replace petition_never_and_oppose=1 if dopposeever==1 & river_bill_id=="38"
	replace petition_never_and_oppose=1 if petition_never==1 & river_bill_id=="38"
	
	/****** first columns appendix table 2 testing characteristics for support***********/
	
	
	ttest rivernav1670 if petition_never_and_support==1, by(dsupportever)

	ttest civicgov1670 if petition_never_and_support==1, by(dsupportever)	

	ttest manufact1670 if petition_never_and_support==1, by(dsupportever)

	ttest mining1670 if petition_never_and_support==1, by(dsupportever)

	ttest harbour1670 if petition_never_and_support==1, by(dsupportever)

	ttest morden1700 if petition_never_and_support==1, by(dsupportever)

	ttest freeschool1670 if petition_never_and_support==1, by(dsupportever)

	
	
	/****** second columns appendix table 2 testing characteristics for support***********/
	
	ttest rivernav1670 if petition_never_and_oppose==1, by(dopposeever)


	ttest civicgov1670 if petition_never_and_oppose==1, by(dopposeever)	

	ttest manufact1670 if petition_never_and_oppose==1, by(dopposeever)

	ttest mining1670 if petition_never_and_oppose==1, by(dopposeever)

	ttest harbour1670 if petition_never_and_oppose==1, by(dopposeever)

	ttest morden1700 if petition_never_and_oppose==1, by(dopposeever)

	ttest freeschool1670 if petition_never_and_oppose==1, by(dopposeever)
	
	
/*****appendix table 3 Logit estimates identifying characteristics associated with towns petitioning in support as opposed to petitioning against river bills   ****/	

	/****** generating variables to identify if a town petitions and petitions supporting and opposing in the same parliament***/
	

	gen petition=.
	replace petition=1 if dsupport==1
	replace petition=1 if doppose==1

	gen petitionboth=.
	replace petitionboth=1 if dsupport==1 & doppose==1
	
	/****** generating interaction variables between downstream and town characteristics***/
	
	gen downstreammorden=downstream*morden1700

	gen downstreamharbour=downstream*harbour1670

	gen downstreamrivernav=downstream*rivernav1670

	gen downstreammanufact=downstream*manufact1670

	gen downstreammining=downstream*mining1670

	gen downstreamschool=downstream*freeschool1670 

	gen downstreamgov=downstream*civicgov1670

		
	dprobit dsupport downstream disttocandidate rivernav1670 localmarket manufact1670 mining1670 harbour1670 morden1700 freeschool1670 civicgov1670 downstreammorden downstreamharbour downstreamrivernav downstreammanufact downstreammining downstreamschool downstreamgov if petition==1 & petitionboth==.

	
	
	
	
/******appendix table 4 adding time varing covariates to check whig majorities********/

		clear

		insheet using rivactpanelaug82016_public.txt


		/******** rescaling variables *****/

		gen popconnectcity1000=popconnectcity/1000


		gen localmarketpotinc1000=localmarketpotinc/1000
	
		gen localmarketpotinc10000=localmarketpotinc/10000


		gen elev10=elev/10
		gen dist10=dist/10

		/******** region parliament trends *****/

		gen yearse=year*southeast
		gen yearsw=year*southwest
		gen yearem=year*eastmid
		gen yearwm=year*westmid
		gen yearno=year*north
		gen yearwa=year*wales
		
		/*****for description of variables see table 4 above*******/

		
	iis cityid

	xtset cityid year2

	tabulate year2, gen(yy)
	

	probit drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa  foreignwar badharvest rorclark  inflation avgrowthcoastal parllength if drivdrop==0, cluster(cityid)

	
	
	
	
/******appendix table 5 pooled probit using 20 miles or 30 miles********/

	/******appendix table 5 column 1 25 miles********/
	probit drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


	/******appendix table 5 column 2 20 miles********/
	probit drivact mps20up_a15 mps20down_a15 rpcounty_m15 rpclosest_j15 rps20up_a15 rps20down_a15 cont20up_a15 cont20down_a15 incum20up_a15 incum20down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour20up harbour20down mining20up mining20down manufact20up manufact20down rivernav20up rivernav20down morden20up morden20down freeschool20up freeschool20down civic20up civic20down north eastmid westmid southwest wales pike20prev river20prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)

		

	/******appendix table 5 column 3 30 miles********/
	probit drivact mps30up_a15 mps30down_a15 rpcounty_m15 rpclosest_j15 rps30up_a15 rps30down_a15 cont30up_a15 cont30down_a15 incum30up_a15 incum30down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour30up harbour30down mining30up mining30down manufact30up manufact30down rivernav30up rivernav30down morden30up morden30down freeschool30up freeschool30down civic30up civic30down north eastmid westmid southwest wales pike30prev river30prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


/***appendix table 6 all coefficient estimates for placebo test using left right model indicators rather than upstream and downstream***/


	probit drivact  mps25left_a15 mps25right_a15 rpcounty_m15 rpclosest_j15 rps25left_a15 rps25right_a15 cont25left_a15 cont25right_a15 incum25left_a15 incum25right_a15 whig elev10 dist10 localmarketpotinc10000 popconnectcity1000 harbour25left harbour25right mining25left mining25right manufact25left manufact25right rivernav25left rivernav25right morden25left morden25right freeschool25left freeschool25right civic25left civic25right pike25prev year  if drivbill==1, robust



	probit drivact mps25left_a15 mps25right_a15 rpcounty_m15 rpclosest_j15 rps25left_a15 rps25right_a15 cont25left_a15 cont25right_a15 incum25left_a15 incum25right_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25left harbour25right mining25left mining25right manufact25left manufact25right rivernav25left rivernav25right morden25left morden25right freeschool25left freeschool25right civic25left civic25right north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)



/*******appendix table 7 heckman probit model********/

		heckprob drivact  mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down civic25up civic25down  localmarketpotinc10000 popconnectcity1000 year  if drivdrop==0, select(drivbill=mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa) vce(cluster cityid)


		
/*****appendix table 8  fe models, variation across candidate towns with river bills*****/
	
		xtreg drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa if drivdrop== 0 & driverbill1690_1741==1, fe cluster(cityid)


		xtscc drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa if drivdrop== 0 & driverbill1690_1741==1, fe 


		xtpcse drivact rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 elev10 dist10 pike25prev river25prev yy2 yy3 yy4 yy5 yy6 yy7 yy8 yy9 yy10 yy11 yy12 yy13 yy14 yearsw yearem yearwm yearno yearwa i.cityid if drivdrop== 0 & driverbill1690_1741==1, correlation(ar1) 


/***** appendix figure 5 histogram towns share of incumbent mps***/

	/***generate variables for variation in majority party MPs from incumbents***/

		gen rpclosestendog=rpclosest_j15- rpclosestexog
		gen rps25downendog_a15= rps25down_a15- rps25downexog_a15
		gen rps25upendog_a15= rps25up_a15- rps25upexog_a15
		gen rpcountyendog= rpcounty_m15- rpcountyexog

		replace rpclosestexog=. if year==1695
		replace rps25downexog_a15=. if year==1695
		replace rps25upexog_a15=. if year==1695
		replace rpcountyexog=. if year==1695

		replace rpclosestendog=. if year==1695
		replace rps25downendog_a15=. if year==1695
		replace rps25upendog_a15=. if year==1695
		replace rpcountyendog=. if year==1695

	/***create sub-sample only using variation in majority party MPs from incumbents***/

		probit drivact mps25up mps25down rpcountyexog rpclosestexog rps25upexog_a15 rps25downexog_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000  pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)

		predict www if e(sample)

		gen inexogsample=1
		replace inexogsample=. if www==.



	/***generating a balancing sample for column 3***/
			/** start by identifying towns with high incumbents and low incumbents***/

		gen incumshare=(incum25down_a15+incum25up_a15)/(mps25down_a15 +mps25up_a15)
		gen mps25=mps25down_a15 +mps25up_a15

		
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles ≥0.5***/
			
			gen incumtreat49=0
			replace incumtreat49=1 if incumshare>.4999999
			replace incumtreat49=0 if mps25 ==0
			replace incumtreat49=. if year==1695

					
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles >0.5***/
			
			gen incumtreat50=0
			replace incumtreat50=1 if incumshare>.5
			replace incumtreat50=0 if mps25 ==0
			replace incumtreat50=. if year==1695
			
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles >0.45***/
			
			gen incumtreat45=0
			replace incumtreat45=1 if incumshare>.45
			replace incumtreat45=0 if mps25 ==0
			replace incumtreat45=. if year==1695

			
			/** define Sample restricted to towns with share of incumbent MPs within 25 miles >0.55***/
			
			gen incumtreat55=0
			replace incumtreat55=1 if incumshare>.55
			replace incumtreat55=0 if mps25 ==0
			replace incumtreat55=. if year==1695


		hist incumshare if drivdrop==0 & year>1695
		
		
		
/***** appendix table 9 means analysis more incumbents vs all other town***/


	/***** appendix table 9 columns 1 to 3***/

	ttest elev10 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest dist10 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest harbour1670 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest mining1670 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest manufact1670 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest morden1700 if inexogsample==1 & year>1695,  by(incumtreat49) 

	ttest freeschool1670 if inexogsample==1 & year>1695,  by(incumtreat49) 

	ttest civicgov1670 if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest localmarketpotinc10000 if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest popconnectcity1000 if inexogsample==1 & year>1695, by(incumtreat49) 

	ttest mps25up_a15 if inexogsample==1 & year>1695, by(incumtreat49) 

	ttest mps25down_a15 if inexogsample==1 & year>1695, by(incumtreat49)

	ttest harbour25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest harbour25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest mining25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest mining25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest manufact25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest manufact25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest rivernav25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest rivernav25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest morden25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest morden25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest freeschool25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest freeschool25down if inexogsample==1 & year>1695,  by(incumtreat49) 

	ttest civic25up if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest civic25down if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest north if inexogsample==1 & year>1695,  by(incumtreat49)

	ttest eastmid if inexogsample==1 & year>1695,  by(incumtreat49) 

	ttest westmid if inexogsample==1 & year>1695, by(incumtreat49)

	ttest southwest if inexogsample==1 & year>1695,  by(incumtreat49) 

 
	/***** appendix table 9 columns 4 to 6***/
	
	ttest elev10 if inexogsample==1 & year>1695, by(incumtreat50)

	ttest dist10 if inexogsample==1 & year>1695, by(incumtreat50)

	ttest harbour1670 if inexogsample==1 & year>1695, by(incumtreat50)

	ttest mining1670 if inexogsample==1 & year>1695, by(incumtreat50)

	ttest manufact1670 if inexogsample==1 & year>1695, by(incumtreat50) 

	ttest morden1700 if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest freeschool1670 if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest civicgov1670 if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest localmarketpotinc10000 if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest popconnectcity1000 if inexogsample==1 & year>1695, by(incumtreat50) 

	ttest mps25up_a15 if inexogsample==1 & year>1695, by(incumtreat50) 

	ttest mps25down_a15 if inexogsample==1 & year>1695, by(incumtreat50)

	ttest harbour25up if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest harbour25down if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest mining25up if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest mining25down if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest manufact25up if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest manufact25down if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest rivernav25up if inexogsample==1 & year>1695,  by(incumtreat50)  

	ttest rivernav25down if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest morden25up if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest morden25down if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest freeschool25up if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest freeschool25down if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest civic25up if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest civic25down if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest north if inexogsample==1 & year>1695,  by(incumtreat50)

	ttest eastmid if inexogsample==1 & year>1695,  by(incumtreat50) 

	ttest westmid if inexogsample==1 & year>1695, by(incumtreat50)

	ttest southwest if inexogsample==1 & year>1695,  by(incumtreat50) 


/****Appendix table 10 Omnibus tests for towns with incumbent MPs within 25 miles****/
	
			/***NOTE R code to check balance in towns with many incumbents, used in appendix table 10***/
			
			/****R code*****/
		
		install.packages("optmatch")

		install.packages("RItools", dependencies=T)

		library(optmatch)
		library(RItools)
		
		mydata = read.csv("actsampleaug82016.csv")
		
		
		/*****Panel A: Treatment=1 if town’s share of incumb. MPs within 25 mi. is greater than or equal to 0.5; 0 otherwise***/
		
		xBalance(incumtreat49~ elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat49~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat49~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest + elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))


		
		/*****Panel B: Treatment=1 if town’s share of incumbent MPs within 25 mi. is greater than 0.5; 0 otherwise*****/
		
		xBalance(incumtreat50~ elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat50~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat50~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest + elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		/****Panel C: Treatment=1 if town’s share of incumbent MPs within 25 mi. is greater than 0.45; 0 otherwise****/
		
		xBalance(incumtreat45~ elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat45~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat45~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest + elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))


		Panel D: Treatment=1 if town’s share of incumbent MPs within 25 mi. is greater than 0.55; 0 otherwise
		
		xBalance(incumtreat55~ elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat55~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		xBalance(incumtreat55~ mps25up_a15 + mps25down_a15 + harbour25up + harbour25down +  mining25up +  mining25down + manufact25up + manufact25down + rivernav25up + rivernav25down +  morden25up +  morden25down + freeschool25up + freeschool25down + civic25up + civic25down + north + eastmid +  westmid + southwest + elev10 + dist10 + harbour1670 + mining1670 + manufact1670 + morden1700 + freeschool1670 + civicgov1670 + localmarketpotinc10000 + popconnectcity1000, data=mydata, report=c("adj.means", "std.diffs", "z.scores", "chisquare.test"))

		
		
		/***R code end ***/
		
		
/****appendix table 11 : Moment distributions after entropy balancing using downstream incumbent majority party MPs as the treatment *****/


	/***generate variable for share of downstream incumbents who were with the majority party and then treatment for share greater than or equal to half ***/
		gen rp25downexogshareincum=rps25downexog_a15/incum25down_a15

		
			/****note that if there are no incumbents downstream then the share is zero. Also the year 1695 is dropped as no incumbents are defined***/
			gen rp25downexogincumtreatp50=0
			replace rp25downexogincumtreatp50=1 if rp25downexogshareincum>.50
			replace rp25downexogincumtreatp50=0 if incum25down_a15==0
			replace rp25downexogincumtreatp50=. if year==1695

			gen rp25downexogincumtreatp49=0
			replace rp25downexogincumtreatp49=1 if rp25downexogshareincum>.4999999
			replace rp25downexogincumtreatp49=0 if incum25down_a15==0
			replace rp25downexogincumtreatp49=. if year==1695

			/**** generate a dummy variable for towns with no incumbent MPs downstream. becomes a control below***/	
			gen nonincum25down=0
			replace nonincum25down=1 if incum25down_a15==0


			/*** use ebalance command to create a balance sample for treatment group***/
			ebalance rp25downexogincumtreatp50 nonincum25down mps25up_a15 mps25down_a15 elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales if inexogsample==1 

			gen weightrpdownincumdowntreatp50=_webal
			drop _webal
			
			/*** only After:  _webal as the weighting variable is shown in appendix table 11 ***/
			
			
/****appendix table 12 Results from Entropy Balancing using treatment and control towns *****/


	/*** column 1 appendix table 12****/

		probit drivact rp25downexogincumtreatp50 nonincum25down mps25up mps25down cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa [pw=weightrpdownincumdowntreatp50] if inexogsample==1, cluster(cityid)


		margins, at( rp25downexogincumtreatp50 ==( 0 1))
		
			/*** column 2 appendix table 12****/
		
		probit drivact rp25downexogincumtreatp50 nonincum25down mps25up mps25down cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if inexogsample==1, cluster(cityid)

		margins, at( rp25downexogincumtreatp50 ==( 0 1))
		
		
		
/******appendix table 13 predicted probabilities of getting river act by parliament, party interactions********/


		probit drivact mps25up_a15 mps25down_a15 c.rpcounty_m15 c.rpclosest_j15 c.rps25up_a15 c.rps25down_a15 cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 i.whig i.whig#c.rps25down_a15 i.whig#c.rps25up_a15 i.whig#c.rpclosest_j15 i.whig#c.rpcounty_m15 elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


		margins whig, at(rps25down_a15==(0(1)10) )

		marginsplot, legend(order(1 "Tory Majorities" 2 "Whig Majorities")) xtitle(Maj. MPs Downstream) ytitle(Pred. Prob. Act) title(Predicted Margins Whig and Tory Majority Party MPs Downstream) recast(line) recastci(rarea) ci1opts(fintensity(30))  ciopts(color(gs10))  ci2opts(fintensity(90))  plot1opts(lcolor(gs7))  plot2opts(lcolor(gs20)) 

		margins whig, at(rps25up_a15==(0(1)10) )

		marginsplot, legend(order(1 "Tory Majorities" 2 "Whig Majorities")) xtitle(Maj. MPs Upstream) ytitle(Pred. Prob. Act) title(Predicted Margins Whig and Tory Majority Party MPs Upstream) recast(line) recastci(rarea) ci1opts(fintensity(30))  ciopts(color(gs10))  ci2opts(fintensity(90))  plot1opts(lcolor(gs7))  plot2opts(lcolor(gs20)) 

		margins whig, at(rpcounty_m15==(0(1)2) )

		marginsplot, legend(order(1 "Tory Majorities" 2 "Whig Majorities")) xtitle(Maj. MPs County) ytitle(Pred. Prob. Act) title(Predicted Margins Whig and Tory Majority Party MPs County) recast(line) recastci(rarea) ci1opts(fintensity(30))  ciopts(color(gs10))  ci2opts(fintensity(90))  plot1opts(lcolor(gs7))  plot2opts(lcolor(gs20)) 

		margins whig, at(rpclosest_j15==(0(1)2) )

		marginsplot, legend(order(1 "Tory Majorities" 2 "Whig Majorities")) xtitle(Maj. MPs Closest Constituency) ytitle(Pred. Prob. Act) title(Predicted Margins Whig and Tory Majority Party MPs Closest Constit.) recast(line) recastci(rarea) ci1opts(fintensity(30))  ciopts(color(gs10))  ci2opts(fintensity(90))  plot1opts(lcolor(gs7))  plot2opts(lcolor(gs20)) 


/******appendix table 14, Probit Estimates in specifications including party strongholds and interactions with contests****/


	/*****appendix table 14 column 1, river act adoption model after adding majority party strongholds*****/

		gen strongdown=0
		replace strongdown=whigstrong0115_25down_a15 if whig==1
		replace strongdown=torystrong0115_25down_a15 if whig==0

		gen strongup=0
		replace strongup=whigstrong0115_25up_a15 if whig==1
		replace strongup=torystrong0115_25up_a15 if whig==0

		gen strongcounty=0
		replace strongcounty=rpcountywhigstrong0115 if whig==1
		replace strongcounty=rpcountytorystrong0115 if whig==0


		probit drivact mps25up_a15 mps25down_a15 rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 strongup strongdown strongcounty cont25up_a15 cont25down_a15 incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


	/******appendix table 14 column 2 river act adoption model after adding majority party vars interacted with contests*****/

		probit drivact mps25up mps25down rpcounty_m15 rpclosest_j15 rps25up_a15 rps25down_a15 cont25up_a15 cont25down_a15 countycont rps25contup_a15 rps25contdown_a15 rpcountycont rpclosestcont incum25up_a15 incum25down_a15 whig elev10 dist10 harbour1670 mining1670 manufact1670 morden1700 freeschool1670 civicgov1670 localmarketpotinc10000 popconnectcity1000 harbour25up harbour25down mining25up mining25down manufact25up manufact25down rivernav25up rivernav25down morden25up morden25down freeschool25up freeschool25down civic25up civic25down north eastmid westmid southwest wales pike25prev river25prev year yearno yearem yearwm yearsw yearwa if drivdrop==0, cluster(cityid)


